@@ -1,6 +1,6 @@
 import times
 from .connections import resolve_connection
-from .job import Job
+from .job import Job, Status
 from .exceptions import NoSuchJobError, UnpickleError, InvalidJobOperationError
 from .compat import total_ordering
 
@@ -41,12 +41,14 @@ class Queue(object):
         name = queue_key[len(prefix):]
         return cls(name, connection=connection)
 
-    def __init__(self, name='default', default_timeout=None, connection=None):
+    def __init__(self, name='default', default_timeout=None, connection=None,
+                 async=True):
         self.connection = resolve_connection(connection)
         prefix = self.redis_queue_namespace_prefix
         self.name = name
         self._key = '%s%s' % (prefix, name)
         self._default_timeout = default_timeout
+        self._async = async
 
     @property
     def key(self):
@@ -71,7 +73,7 @@ class Queue(object):
         """Returns a list of all (valid) jobs in the queue."""
         def safe_fetch(job_id):
             try:
-                job = Job.fetch(job_id, connection=self.connection)
+                job = Job.safe_fetch(job_id, connection=self.connection)
             except NoSuchJobError:
                 return None
             except UnpickleError:
@@ -96,7 +98,7 @@ class Queue(object):
             job_id = self.connection.lpop(COMPACT_QUEUE)
             if job_id is None:
                 break
-            if Job.exists(job_id):
+            if Job.exists(job_id, self.connection):
                 self.connection.rpush(self.key, job_id)
 
 
@@ -104,7 +106,7 @@ class Queue(object):
         """Pushes a job ID on the corresponding Redis queue."""
         self.connection.rpush(self.key, job_id)
 
-    def enqueue_call(self, func, args=None, kwargs=None, timeout=None):
+    def enqueue_call(self, func, args=None, kwargs=None, timeout=None, result_ttl=None): #noqa
         """Creates a job to represent the delayed function call and enqueues
         it.
 
@@ -113,7 +115,8 @@ class Queue(object):
         contain options for RQ itself.
         """
         timeout = timeout or self._default_timeout
-        job = Job.create(func, args, kwargs, connection=self.connection)
+        job = Job.create(func, args, kwargs, connection=self.connection,
+                         result_ttl=result_ttl, status=Status.QUEUED)
         return self.enqueue_job(job, timeout=timeout)
 
     def enqueue(self, f, *args, **kwargs):
@@ -138,14 +141,16 @@ class Queue(object):
         # Detect explicit invocations, i.e. of the form:
         #     q.enqueue(foo, args=(1, 2), kwargs={'a': 1}, timeout=30)
         timeout = None
+        result_ttl = None
         if 'args' in kwargs or 'kwargs' in kwargs:
             assert args == (), 'Extra positional arguments cannot be used when using explicit args and kwargs.'  # noqa
             timeout = kwargs.pop('timeout', None)
             args = kwargs.pop('args', None)
+            result_ttl = kwargs.pop('result_ttl', None)
             kwargs = kwargs.pop('kwargs', None)
 
         return self.enqueue_call(func=f, args=args, kwargs=kwargs,
-                timeout=timeout)
+                                 timeout=timeout, result_ttl=result_ttl)
 
     def enqueue_job(self, job, timeout=None, set_meta_data=True):
         """Enqueues a job for delayed execution.
@@ -156,6 +161,8 @@ class Queue(object):
 
         If the `set_meta_data` argument is `True` (default), it will update
         the properties `origin` and `enqueued_at`.
+
+        If Queue is instantiated with async=False, job is executed immediately.
         """
         if set_meta_data:
             job.origin = self.name
@@ -165,9 +172,13 @@ class Queue(object):
             job.timeout = timeout  # _timeout_in_seconds(timeout)
         else:
             job.timeout = 180  # default
-
         job.save()
-        self.push_job_id(job.id)
+
+        if self._async:
+            self.push_job_id(job.id)
+        else:
+            job.perform()
+            job.save()
         return job
 
     def pop_job_id(self):
