@@ -6,6 +6,8 @@ The formatter for ANSI colored console output is heavily based on Pygments
 terminal colorizing code, originally by Georg Brandl.
 """
 import os
+import sys
+import logging
 
 
 def gettermsize():
@@ -65,12 +67,17 @@ class _Colorizer(object):
         self.codes["darkyellow"] = self.codes["brown"]
         self.codes["fuscia"] = self.codes["fuchsia"]
         self.codes["white"] = self.codes["bold"]
+        self.notty = not sys.stdout.isatty()
+
 
     def reset_color(self):
         return self.codes["reset"]
 
     def colorize(self, color_key, text):
-        return self.codes[color_key] + text + self.codes["reset"]
+        if not sys.stdout.isatty():
+            return text
+        else:
+            return self.codes[color_key] + text + self.codes["reset"]
 
     def ansiformat(self, attr, text):
         """
@@ -115,3 +122,34 @@ def make_colorizer(color):
     def inner(text):
         return colorizer.colorize(color, text)
     return inner
+
+
+class ColorizingStreamHandler(logging.StreamHandler):
+
+    levels = {
+        logging.WARNING: make_colorizer('darkyellow'),
+        logging.ERROR: make_colorizer('darkred'),
+        logging.CRITICAL: make_colorizer('darkred'),
+    }
+
+    def __init__(self, exclude=None, *args, **kwargs):
+        self.exclude = exclude
+        super(ColorizingStreamHandler, self).__init__(*args, **kwargs)
+
+    @property
+    def is_tty(self):
+        isatty = getattr(self.stream, 'isatty', None)
+        return isatty and isatty()
+
+    def format(self, record):
+        message = logging.StreamHandler.format(self, record)
+        if self.is_tty:
+            colorize = self.levels.get(record.levelno, lambda x: x)
+
+            # Don't colorize any traceback
+            parts = message.split('\n', 1)
+            parts[0] = " ".join([parts[0].split(" ", 1)[0], colorize(parts[0].split(" ", 1)[1])])
+
+            message = '\n'.join(parts)
+
+        return message
